@@ -487,6 +487,13 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import automl_v1
 
             def sample_predict():
@@ -655,6 +662,13 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import automl_v1
 
             def sample_batch_predict():
@@ -663,7 +677,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
 
                 # Initialize request argument(s)
                 input_config = automl_v1.BatchPredictInputConfig()
-                input_config.gcs_source.input_uris = ['input_uris_value_1', 'input_uris_value_2']
+                input_config.gcs_source.input_uris = ['input_uris_value1', 'input_uris_value2']
 
                 output_config = automl_v1.BatchPredictOutputConfig()
                 output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
