@@ -41,8 +41,15 @@ class ImageObjectDetectionAnnotation(proto.Message):
             positivity confidence.
     """
 
-    bounding_box = proto.Field(proto.MESSAGE, number=1, message=geometry.BoundingPoly,)
-    score = proto.Field(proto.FLOAT, number=2,)
+    bounding_box = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=geometry.BoundingPoly,
+    )
+    score = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
 
 
 class BoundingBoxMetricsEntry(proto.Message):
@@ -83,15 +90,35 @@ class BoundingBoxMetricsEntry(proto.Message):
                 precision.
         """
 
-        confidence_threshold = proto.Field(proto.FLOAT, number=1,)
-        recall = proto.Field(proto.FLOAT, number=2,)
-        precision = proto.Field(proto.FLOAT, number=3,)
-        f1_score = proto.Field(proto.FLOAT, number=4,)
+        confidence_threshold = proto.Field(
+            proto.FLOAT,
+            number=1,
+        )
+        recall = proto.Field(
+            proto.FLOAT,
+            number=2,
+        )
+        precision = proto.Field(
+            proto.FLOAT,
+            number=3,
+        )
+        f1_score = proto.Field(
+            proto.FLOAT,
+            number=4,
+        )
 
-    iou_threshold = proto.Field(proto.FLOAT, number=1,)
-    mean_average_precision = proto.Field(proto.FLOAT, number=2,)
+    iou_threshold = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    mean_average_precision = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
     confidence_metrics_entries = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=ConfidenceMetricsEntry,
+        proto.MESSAGE,
+        number=3,
+        message=ConfidenceMetricsEntry,
     )
 
 
@@ -116,11 +143,19 @@ class ImageObjectDetectionEvaluationMetrics(proto.Message):
             bounding_box_metrics_entries.
     """
 
-    evaluated_bounding_box_count = proto.Field(proto.INT32, number=1,)
+    evaluated_bounding_box_count = proto.Field(
+        proto.INT32,
+        number=1,
+    )
     bounding_box_metrics_entries = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="BoundingBoxMetricsEntry",
+        proto.MESSAGE,
+        number=2,
+        message="BoundingBoxMetricsEntry",
+    )
+    bounding_box_mean_average_precision = proto.Field(
+        proto.FLOAT,
+        number=3,
     )
-    bounding_box_mean_average_precision = proto.Field(proto.FLOAT, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
