@@ -23,7 +23,12 @@ from google.cloud.automl_v1beta1.types import video
 from google.protobuf import timestamp_pb2  # type: ignore
 
 
-__protobuf__ = proto.module(package="google.cloud.automl.v1beta1", manifest={"Model",},)
+__protobuf__ = proto.module(
+    package="google.cloud.automl.v1beta1",
+    manifest={
+        "Model",
+    },
+)
 
 
 class Model(proto.Message):
@@ -158,14 +163,33 @@ class Model(proto.Message):
         oneof="model_metadata",
         message=text.TextSentimentModelMetadata,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    dataset_id = proto.Field(proto.STRING, number=3,)
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    dataset_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
     update_time = proto.Field(
-        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
+    )
+    deployment_state = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=DeploymentState,
     )
-    deployment_state = proto.Field(proto.ENUM, number=8, enum=DeploymentState,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
